""" 物件新規作成の省力化ツール関数

入力CSVへの書き込み

"""

# ライブラリのインポート --------------------------------------------
import ss7csv
import inputreader
import openpyxl
from openpyxl.utils import get_column_letter, column_index_from_string
from typing import List


def write_mainkozo_s(data: List[List[str]], main_kozo: str) -> None:
    """name=基本事項 主体構造 S

    Args:
        data (List[List[str]]): 入力CSVデータ
        main_kozo (str): 主体構造
    """
    rowindex: int = ss7csv.GetRowIndex_name(data, "name=基本事項", "", "主体構造", "S")
    colindex: int = 3
    data[rowindex][colindex] = "0"
    if "S" in main_kozo:
        data[rowindex][colindex] = "1"


def write_mainkozo_rc(data: List[List[str]], main_kozo: str) -> None:
    """name=基本事項 主体構造 RC

    Args:
        data (List[List[str]]): 入力CSVデータ
        main_kozo (str): 主体構造
    """
    # name=基本事項 主体構造 RC
    rowindex: int = ss7csv.GetRowIndex_name(data, "name=基本事項", "", "主体構造", "S")
    rowindex_rc: int = rowindex + 1  # Sの次の行がRC
    rowindex = rowindex_rc
    colindex: int = 3
    data[rowindex][colindex] = "0"
    if "RC" in main_kozo:
        data[rowindex][colindex] = "1"


def write_routekozo(data: List[List[str]], route_kozo: int) -> None:
    """name=基本事項 計算ルート 構造種別

    Args:
        data (List[List[str]]): 入力CSVデータ
        route_kozo (int): 計算ルート 構造種別
    """
    rowindex: int = ss7csv.GetRowIndex_name(
        data, "name=基本事項", "", "計算ルート", "構造種別"
    )
    colindex: int = 3
    data[rowindex][colindex] = str(route_kozo)


def write_span_x(data: List[List[str]], count_span_x: int) -> None:
    """name=基本事項 X方向スパン数

    Args:
        data (List[List[str]]): 入力CSVデータ
        count_span_x (int): X方向スパン数
    """
    rowindex: int = ss7csv.GetRowIndex_name(
        data, "name=基本事項", "", "建物概要", "X方向スパン数"
    )
    colindex: int = 3
    data[rowindex][colindex] = str(count_span_x)


def write_span_y(data: List[List[str]], count_span_y: int) -> None:
    """name=基本事項 Y方向スパン数

    Args:
        data (List[List[str]]): 入力CSVデータ
        count_span_y (int): Y方向スパン数
    """
    rowindex: int = ss7csv.GetRowIndex_name(data, "name=基本事項", "", "Y方向スパン数")
    colindex: int = 3
    data[rowindex][colindex] = str(count_span_y)


def write_floorcount(data: List[List[str]], count_floor: int) -> None:
    """name=基本事項 全階数

    Args:
        data (List[List[str]]): 入力CSVデータ
        count_floor (int): 全階数
    """
    rowindex: int = ss7csv.GetRowIndex_name(data, "name=基本事項", "", "全階数")
    colindex: int = 3
    data[rowindex][colindex] = str(count_floor)


def write_linename(
    data: List[List[str]],
    name_line: List[str],
    count_span_x: int,
    count_span_y: int,
) -> None:
    """name=軸名

    Args:
        data (List[List[str]]): 入力CSVデータ
        name_line (List[str]): 軸名
        count_span_x (int): X方向スパン数
        count_span_y (int): Y方向スパン数
    """
    rowindex: int = ss7csv.GetDataRowIndex(data, "name=軸名")
    # ひな型の軸名を削除　※登録済みの４軸
    for i in range(4):
        del data[rowindex]  # 削除していくので同じインデックスを削除
    # 軸名の追加
    for i in range(count_span_x + count_span_y + 2):
        data.insert(rowindex + i, [name_line[i], "<RE>"])


def write_linezname(
    data: List[List[str]], name_linez: List[str], count_linez: int
) -> None:
    """name=層名

    Args:
        data (List[List[str]]): 入力CSVデータ
        name_linez (List[str]): 層名
        count_linez (int): 層数
    """
    rowindex: int = ss7csv.GetDataRowIndex(data, "name=層名")
    # ひな型の層名を削除　※登録済みの２層
    for i in range(2):
        del data[rowindex]  # 削除していくので同じインデックスを削除
    # 層名の追加
    for i in range(count_linez):
        data.insert(rowindex + i, [name_linez[i], "<RE>"])


def write_floorname(
    data: List[List[str]], name_floor: List[str], count_floor: int
) -> None:
    """name=階名

    Args:
        data (List[List[str]]): 入力CSVデータ
        name_floor (List[str]): 階名
        count_floor (int): 階数
    """
    rowindex: int = ss7csv.GetDataRowIndex(data, "name=階名")
    # ひな型の階名を削除　※登録済みの１階
    for i in range(1):
        del data[rowindex]  # 削除していくので同じインデックスを削除
    # 階名の追加
    for i in range(count_floor):
        data.insert(rowindex + i, [name_floor[i], "<RE>"])


def write_linezkozo(
    data: List[List[str]],
    main_kozo: str,
    name_linez: List[str],
    count_linez: int,
) -> None:
    """name=各層主体構造

    Args:
        data (List[List[str]]): 入力CSVデータ
        main_kozo (str): 各層主体構造
        name_linez (List[str]): 層名
        count_linez (int): 層数
    """
    rowindex: int = ss7csv.GetDataRowIndex(data, "name=各層主体構造")
    # ひな型の各層主体構造を削除　※登録済みの２層
    for i in range(2):
        del data[rowindex]  # 削除していくので同じインデックスを削除
    # 各層主体構造の追加
    for i in range(count_linez):
        if main_kozo == "S" and i == count_linez - 1:  # 主体構造S造 最下層
            data.insert(rowindex + i, [name_linez[i], "RC", "<RE>"])
        else:
            data.insert(rowindex + i, [name_linez[i], main_kozo, "<RE>"])


def write_span_length(
    data: List[List[str]],
    span_x: List[float],
    span_y: List[float],
    name_line_x: List[str],
    name_line_y: List[str],
    count_span_x: int,
    count_span_y: int,
) -> None:
    """name=基準スパン長

    Args:
        data (List[List[str]]): 入力CSVデータ
        span_x (List[float]): X方向基準スパン長
        span_y (List[float]): Y方向基準スパン長
        name_line_x (List[str]): X軸名
        name_line_y (List[str]): Y軸名
        count_span_x (int): Xスパン数
        count_span_y (int): Yスパン数
    """
    rowindex: int = ss7csv.GetDataRowIndex(data, "name=基準スパン長")
    # ひな型の基準スパン長を削除　※登録済みの２スパン
    for i in range(2):
        del data[rowindex]  # 削除していくので同じインデックスを削除
    # 基準スパン長の追加
    for i in range(count_span_x):
        # X軸スパン
        name_line_line: str = name_line_x[i] + "－" + name_line_x[i + 1]
        data.insert(rowindex + i, [name_line_line, str(span_x[i]), "<RE>"])
    for i in range(count_span_y):
        # Y軸スパン
        index_y: int = rowindex + count_span_x
        name_line_line = name_line_y[i] + "－" + name_line_y[i + 1]
        data.insert(index_y + i, [name_line_line, str(span_y[i]), "<RE>"])


def write_floor_height(
    data: List[List[str]],
    height_floor: List[float],
    name_floor: List[str],
    count_floor: int,
) -> None:
    """name=標準階高

    Args:
        data (List[List[str]]): 入力CSVデータ
        height_floor (List[float]): 標準階高
        name_floor (List[str]): 階名
        count_floor (int): 階数
    """
    rowindex: int = ss7csv.GetDataRowIndex(data, "name=標準階高")
    # ひな型の標準階高を削除　※登録済みの１階
    for i in range(1):
        del data[rowindex]  # 削除していくので同じインデックスを削除
    # 標準階高の追加
    for i in range(count_floor):
        data.insert(rowindex + i, [name_floor[i], str(height_floor[i]), "<RE>"])


def write_gircenter(data: List[List[str]], name_linez: List[str]) -> None:
    """name=標準階高と梁心の差　の初期化

    Args:
        data (List[List[str]]): 入力CSVデータ
        name_linez (List[str]): 層名
    """
    ss7csv.Init_Record(data, "name=標準階高と梁心の差", name_linez, 0)


def write_kozocenter(data: List[List[str]], name_line: List[str]) -> None:
    """name=構造心とのズレ　の初期化

    Args:
        data (List[List[str]]): 入力CSVデータ
        name_line (List[str]): 軸名
    """
    ss7csv.Init_Record(data, "name=構造心とのズレ", name_line, 0)


def write_offset_xy(data: List[List[str]], name_line: List[str]) -> None:
    """name=部材の寄り　の初期化

    Args:
        data (List[List[str]]): 入力CSVデータ
        name_line (List[str]): 軸名
    """
    tablename: str = "name=部材の寄り"
    # レコードを削除
    ss7csv.Delete_Record(data, tablename)
    # レコード開始位置
    rowindex: int = ss7csv.GetDataRowIndex(data, tablename)
    # 初期値を追加
    for i in range(len(name_line)):
        data.insert(rowindex + i, [name_line[i], "中心", "0", "0", "0", "<RE>"])


def write_offset_ud(data: List[List[str]], name_linez: List[str]) -> None:
    """name=梁のレベル調整　の初期化

    Args:
        data (List[List[str]]): 入力CSVデータ
        name_linez (List[str]): 層名
    """
    tablename: str = "name=梁のレベル調整"
    # レコードを削除
    ss7csv.Delete_Record(data, tablename)
    # レコード開始位置
    rowindex: int = ss7csv.GetDataRowIndex(data, tablename)
    # 初期値を追加
    for i in range(len(name_linez)):
        data.insert(rowindex + i, [name_linez[i], "上面", "0", "<RE>"])


def write_doubleslab(data: List[List[str]], name_linez: List[str]) -> None:
    """name=二重スラブの有無　の初期化

    Args:
        data (List[List[str]]): 入力CSVデータ
        name_linez (List[str]): 層名
    """
    ss7csv.Init_Record_str(data, "name=二重スラブの有無", name_linez, "なし")


def write_slab_area(data: List[List[str]], name_linez: List[str]) -> None:
    """name=各層床面積　の初期化

    Args:
        data (List[List[str]]): 入力CSVデータ
        name_linez (List[str]): 層名
    """
    ss7csv.Init_Record(data, "name=各層床面積", name_linez, 0)


def write_linez_dummy(data: List[List[str]], name_linez: List[str]) -> None:
    """name=ダミー層　の初期化

    Args:
        data (List[List[str]]): 入力CSVデータ
        name_linez (List[str]): 層名
    """
    ss7csv.Init_Record(data, "name=ダミー層", name_linez, 0)
    tablename: str = "name=ダミー層"
    # レコードを削除
    ss7csv.Delete_Record(data, tablename)
    # レコード開始位置
    rowindex: int = ss7csv.GetDataRowIndex(data, tablename)
    # 初期値を追加
    for i in range(len(name_linez)):
        data.insert(rowindex + i, [name_linez[i], "通常層", "", "<RE>"])


def write_concmate(data: List[List[str]], concmate: str) -> None:
    """name=標準使用材料 tab=コンクリート・鉄筋

    Args:
        data (List[List[str]]): 入力CSVデータ
        concmate (str): コンクリート材料
    """
    rowindex: int = ss7csv.GetRowIndex_name(
        data, "name=標準使用材料", "tab=コンクリート・鉄筋", "コンクリート", "RC・SRC"
    )
    colindex: int = 4
    data[rowindex][colindex] = concmate


def write_steelmate_gir(data: List[List[str]], steelmate: str) -> None:
    """name=標準使用材料 tab=鉄骨 鉄骨材料 大梁

    Args:
        data (List[List[str]]): 入力CSVデータ
        steelmate (str): 鉄骨材料
    """
    rowindex: int = ss7csv.GetRowIndex_name(
        data, "name=標準使用材料", "tab=鉄骨", "鉄骨材料", "大梁"
    )
    colindex: int = 4
    data[rowindex][colindex] = steelmate  # 端部
    data[rowindex + 1][colindex] = steelmate  # 中央


def write_steelmate_col(data: List[List[str]], steelkind: str, steelmate: str) -> None:
    """name=標準使用材料 tab=鉄骨 鉄骨材料 柱 角形鋼管

    Args:
        data (List[List[str]]): 入力CSVデータ
        steelkind (str): 鋼材の種類
        steelmate (str): 鉄骨材料
    """
    rowindex: int = ss7csv.GetRowIndex_name(
        data, "name=標準使用材料", "tab=鉄骨", "", "柱", "角形鋼管"
    )
    colindex: int = 4
    if steelkind == "角形鋼管":
        data[rowindex][colindex] = steelmate
    elif steelkind == "円形鋼管":
        data[rowindex + 2][colindex] = steelmate


def write_colpos(
    data: List[List[str]],
    fugo_col: List[str],
    name_floor: List[str],
    name_line_x: List[str],
    name_line_y: List[str],
    count_floor: int,
    count_span_x: int,
    count_span_y: int,
) -> None:
    """name=柱配置

    Args:
        data (List[List[str]]): 入力CSVデータ
        fugo_col (List[str]): 柱符号リスト
        name_floor (List[str]): 階名
        name_line_x (List[str]): X軸名
        name_line_y (List[str]): Y軸名
        count_floor (int): 階数
        count_span_x (int): Xスパン数
        count_span_y (int): Yスパン数
    """
    tablename: str = "name=柱配置"
    # レコードを削除
    ss7csv.Delete_Record(data, tablename)
    # レコード開始位置
    rowindex: int = ss7csv.GetDataRowIndex(data, tablename)
    # 値を追加
    index: int = 0
    for floor in range(count_floor):
        fugo_index: int = 0
        for line_x in range(count_span_x + 1):
            for line_y in range(count_span_y + 1):
                data.insert(
                    rowindex + index,
                    [
                        name_floor[floor],
                        " "
                        + name_line_x[line_x]
                        + " "
                        + "-"
                        + " "
                        + name_line_y[line_y],
                        fugo_col[fugo_index],
                        "NO",
                        "NO",
                        "<RE>",
                    ],
                )
                index += 1
                fugo_index += 1


def write_girpos(
    data: List[List[str]],
    fugo_gir: List[str],
    name_linez: List[str],
    name_line_x: List[str],
    name_line_y: List[str],
    count_linez: int,
    count_span_x: int,
    count_span_y: int,
) -> None:
    """name=大梁配置

    Args:
        data (List[List[str]]): 入力CSVデータ
        fugo_gir (List[str]): 梁符号リスト
        name_linez (List[str]): 層名
        name_line_x (List[str]): X軸名
        name_line_y (List[str]): Y軸名
        count_linez (int): 層数
        count_span_x (int): Xスパン数
        count_span_y (int): Yスパン数
    """
    tablename: str = "name=大梁配置"
    # レコードを削除
    ss7csv.Delete_Record(data, tablename)
    # レコード開始位置
    rowindex: int = ss7csv.GetDataRowIndex(data, tablename)
    # 値を追加
    index: int = 0
    for linez in range(count_linez):

        fugo_index: int = 0
        # X方向の梁
        for line_y in range(count_span_y + 1):
            for line_x in range(count_span_x):
                frame_jiku_jiku: str = (
                    " "
                    + name_line_y[line_y]
                    + " - "
                    + name_line_x[line_x]
                    + " - "
                    + name_line_x[line_x + 1]
                )
                data.insert(
                    rowindex + index,
                    [
                        name_linez[linez],
                        frame_jiku_jiku,
                        fugo_gir[fugo_index],
                        "左-右",
                        "<RE>",
                    ],
                )
                index += 1
                fugo_index += 1
        # Y方向の梁
        for line_x in range(count_span_x + 1):
            for line_y in range(count_span_y):
                frame_jiku_jiku = (
                    " "
                    + name_line_x[line_x]
                    + " - "
                    + name_line_y[line_y]
                    + " - "
                    + name_line_y[line_y + 1]
                )
                data.insert(
                    rowindex + index,
                    [
                        name_linez[linez],
                        frame_jiku_jiku,
                        fugo_gir[fugo_index],
                        "左-右",
                        "<RE>",
                    ],
                )
                index += 1
                fugo_index += 1


def write_slab_load(data: List[List[str]], Load: float) -> None:
    """name=床総荷重

    Args:
        data (List[List[str]]): 入力CSVデータ
        Load (float): 床総荷重
    """
    tablename = "name=床総荷重"
    record: List[str] = ss7csv.GetTableData(data, tablename)[0]  # 登録済みの１レコード
    record[2] = str(Load)
    record[3] = str(Load)
    record[4] = str(Load)
    record[5] = str(Load)


def write_slab_pos(
    data: List[List[str]],
    name_linez: List[str],
    name_line_x: List[str],
    name_line_y: List[str],
    count_linez: int,
    count_span_x: int,
    count_span_y: int,
) -> None:
    """name=床配置

    Args:
        data (List[List[str]]): 入力CSVデータ
        name_linez (List[str]): 層名
        name_line_x (List[str]): X軸名
        name_line_y (List[str]): Y軸名
        count_linez (int): 層数
        count_span_x (int): Xスパン数
        count_span_y (int): Yスパン数
    """
    tablename: str = "name=床配置"
    record = ss7csv.GetTableData(data, tablename)[0]  # 登録済みの１レコード
    # レコードを削除
    ss7csv.Delete_Record(data, tablename)
    # レコード開始位置
    rowindex: int = ss7csv.GetDataRowIndex(data, tablename)
    index: int = 0
    for linez in range(count_linez):
        for line_x in range(count_span_x):
            for line_y in range(count_span_y):
                jiku4: str = " " + name_line_y[line_y] + " - " + name_line_y[line_y + 1]
                jiku4 += " - "
                jiku4 += name_line_x[line_x] + " - " + name_line_x[line_x + 1]

                record1 = record.copy()  # ひな形のレコードをもとにコピーを生成
                record1[0] = name_linez[linez]
                record1[1] = jiku4
                data.insert(rowindex + index, record1)
                index += 1


def write_rc_col_sect(
    data: List[List[str]],
    fugo_col: List[str],
    Dcx: float,
    Dcy: float,
    name_floor: List[str],
    count_floor: int,
) -> None:
    """name=RC柱断面

    Args:
        data (List[List[str]]): 入力CSVデータ
        fugo_col (List[str]): 柱符号
        Dcx (float): 柱せい（X方向）
        Dcy (float): 柱せい（Y方向）
        name_floor (List[str]): 階名
        count_floor (int): 階数
    """
    tablename: str = "name=RC柱断面"
    record = ss7csv.GetTableData(data, tablename)[0]  # 登録済みの１レコード
    # レコードを削除
    ss7csv.Delete_Record(data, tablename)
    # レコード開始位置
    rowindex: int = ss7csv.GetDataRowIndex(data, tablename)

    index: int = 0
    for floor in range(count_floor):
        for fugo in fugo_col:
            record1: List[str] = record.copy()  # ひな形のレコードをもとにコピーを生成
            record1[0] = name_floor[floor]
            record1[1] = fugo
            record1[2] = str(count_floor - floor)
            record1[3] = "□"
            record1[4] = str(Dcx)
            record1[5] = str(Dcy)
            data.insert(rowindex + index, record1)
            index += 1


def write_s_col_sect(
    data: List[List[str]],
    fugo_col: List[str],
    steelkind_col: str,
    strSize: str,
    strType: str,
    name_floor: List[str],
    count_floor: int,
) -> None:
    """name=S柱断面

    Args:
        data (List[List[str]]): 入力CSVデータ
        fugo_col (List[str]): 柱符号
        steelkind_col (str): 鋼材の種類
        strSize (str): 鋼材のサイズ
        strType (str): 鋼材の系列
        name_floor (List[str]): 階名
        count_floor (int): 階数
    """
    tablename: str = "name=S柱断面"
    record = ss7csv.GetTableData(data, tablename)[0]  # 登録済みの１レコード
    # レコードを削除
    ss7csv.Delete_Record(data, tablename)
    # レコード開始位置
    rowindex: int = ss7csv.GetDataRowIndex(data, tablename)

    steelkind = ""
    if "H形鋼１" in steelkind_col or "H形鋼２" in steelkind_col:
        steelkind = "Ｈ"
    elif "角形鋼管" in steelkind_col:
        steelkind = "□"
    elif "円形鋼管" in steelkind_col:
        steelkind = "○"

    index: int = 0
    for floor in range(count_floor):
        for fugo in fugo_col:
            record1: List[str] = record.copy()  # ひな形のレコードをもとにコピーを生成
            record1[0] = name_floor[floor]
            record1[1] = fugo
            record1[2] = str(count_floor - floor)
            record1[3] = steelkind
            record1[4] = strSize
            record1[5] = strType
            data.insert(rowindex + index, record1)
            index += 1


def write_rc_gir_sect(
    data: List[List[str]],
    fugo_gir: List[str],
    Bb: float,
    Db: float,
    FBb: float,
    FDb: float,
    name_linez: List[str],
    start_linez: int,
    count_linez: int,
) -> None:
    """name=RC梁断面

    Args:
        data (List[List[str]]): 入力CSVデータ
        fugo_gir (List[str]): 梁符号
        Bb (float): 梁幅
        Db (float): 梁せい
        FBb (float): 基礎梁幅
        FDb (float): 基礎梁せい
        name_linez (List[str]): 層名
        start_linez (int): 層開始インデックス
        count_linez (int): 層数
    """
    tablename: str = "name=RC梁断面"
    record = ss7csv.GetTableData(data, tablename)[0]  # 登録済みの１レコード
    # レコードを削除
    ss7csv.Delete_Record(data, tablename)
    # レコード開始位置
    rowindex: int = ss7csv.GetDataRowIndex(data, tablename)
    index: int = 0
    for linez in range(start_linez, count_linez):
        for fugo in fugo_gir:
            record1: List[str] = record.copy()  # ひな形のレコードをもとにコピーを生成
            record1[0] = name_linez[linez]
            record1[1] = fugo
            record1[2] = str(count_linez - linez)
            if linez == 0:  # 最上層
                record1[2] = "R"
            record1[3] = str(0)
            record1[4] = str(0)
            if linez < count_linez - 1:  # 最下層以外
                record1[5] = str(Bb)
                record1[6] = str(Db)
                record1[7] = str(Bb)
                record1[8] = str(Db)
                record1[9] = str(Bb)
                record1[10] = str(Db)
            else:  # 最下層
                record1[5] = str(FBb)
                record1[6] = str(FDb)
                record1[7] = str(FBb)
                record1[8] = str(FDb)
                record1[9] = str(FBb)
                record1[10] = str(FDb)
            data.insert(rowindex + index, record1)
            index += 1


def write_s_gir_sect(
    data: List[List[str]],
    fugo_gir: List[str],
    steelkind_gir: str,
    strH: str,
    Type_H: str,
    name_linez: List[str],
    start_linez: int,
    count_linez: int,
) -> None:
    """name=S梁断面

    Args:
        data (List[List[str]]): 入力CSVデータ
        fugo_gir (List[str]): 梁符号
        steelkind_gir (str): 鋼材の種類
        strH (str): 鋼材のサイズ
        Type_H (str): 鋼材の系列
        name_linez (List[str]): 層名
        start_linez (int): 層開始インデックス
        count_linez (int): 層数
    """
    tablename: str = "name=S梁断面"
    record = ss7csv.GetTableData(data, tablename)[0]  # 登録済みの１レコード
    # レコードを削除
    ss7csv.Delete_Record(data, tablename)
    # レコード開始位置
    rowindex: int = ss7csv.GetDataRowIndex(data, tablename)

    steelkind: str = ""
    if "H形鋼１" in steelkind_gir or "H形鋼２" in steelkind_gir:
        steelkind = "Ｈ"
    elif "角形鋼管" in steelkind_gir:
        steelkind = "□"
    elif "円形鋼管" in steelkind_gir:
        steelkind = "○"

    index: int = 0
    for linez in range(start_linez, count_linez):
        for fugo in fugo_gir:
            record1: List[str] = record.copy()  # ひな形のレコードをもとにコピーを生成
            record1[0] = name_linez[linez]
            record1[1] = fugo
            record1[2] = str(count_linez - linez)
            if linez == 0:  # 最上層
                record1[2] = "R"
            record1[3] = str(0)
            record1[4] = str(0)
            record1[5] = steelkind
            record1[6] = strH
            record1[7] = Type_H
            record1[8] = strH
            record1[9] = Type_H
            record1[10] = strH
            record1[11] = Type_H
            data.insert(rowindex + index, record1)
            index += 1


def write_steel_h(
    data: List[List[str]],
    wb: openpyxl.Workbook,
    steelkind: str,
    steeltype: str,
) -> None:
    """name=Ｈ形鋼

    Args:
        data (List[List[str]]): 入力CSVデータ
        wb (openpyxl.Workbook): SS7物件新規作成ツール.xlsm
        steelkind (str): 鋼材の種類
        steeltype (str): 鋼材の系列
    """
    tablename: str = "name=Ｈ形鋼"
    record = ss7csv.GetTableData(data, tablename)[0]  # 登録済みの１レコード
    # レコードを削除
    ss7csv.Delete_Record(data, tablename)
    # レコード開始位置
    rowindex: int = ss7csv.GetDataRowIndex(data, tablename)

    # 鋼材リストシート
    sheetH = wb[steelkind]

    # 鋼材の系列の開始列
    start_col: str = inputreader.get_steel_list_pos_startcol(steelkind, steeltype)
    end_row: int = inputreader.get_steel_list_pos_endrow(steelkind, steeltype)

    index: int = 0
    for row in range(4, end_row):
        record1: List[str] = record.copy()  # ひな形のレコードをもとにコピーを生成
        record1[0] = str(index + 1)
        for i in range(7):
            cellname = get_column_letter(column_index_from_string(start_col) + i)
            cellname += str(row)
            record1[i + 1] = str(sheetH[cellname].value)
        data.insert(rowindex + index, record1)
        index += 1


def write_steel_box(
    data: List[List[str]],
    wb: openpyxl.Workbook,
    steelkind: str,
    steeltype: str,
) -> None:
    """name=角形鋼管

    Args:
        data (List[List[str]]): 入力CSVデータ
        wb (openpyxl.Workbook): SS7物件新規作成ツール.xlsm
        steelkind (str): 鋼材の種類
        steeltype (str): 鋼材の系列
    """
    tablename: str = "name=角形鋼管"
    record = ss7csv.GetTableData(data, tablename)[0]  # 登録済みの１レコード
    # レコードを削除
    ss7csv.Delete_Record(data, tablename)
    # レコード開始位置
    rowindex: int = ss7csv.GetDataRowIndex(data, tablename)

    # 鋼材リストシート
    sheetBox = wb[steelkind]

    # 鋼材の系列の開始列
    start_col: str = inputreader.get_steel_list_pos_startcol(steelkind, steeltype)
    end_row: int = inputreader.get_steel_list_pos_endrow(steelkind, steeltype)

    index: int = 0
    for row in range(4, end_row):
        record1: List[str] = record.copy()  # ひな形のレコードをもとにコピーを生成
        record1[0] = str(index + 1)
        for i in range(7):
            cellname = get_column_letter(column_index_from_string(start_col) + i)
            cellname += str(row)
            record1[i + 1] = str(sheetBox[cellname].value)
        data.insert(rowindex + index, record1)
        index += 1


def write_steel_pipe(
    data: List[List[str]],
    wb: openpyxl.Workbook,
    steelkind: str,
    steeltype: str,
) -> None:
    """name=円形鋼管

    Args:
        data (List[List[str]]): 入力CSVデータ
        wb (openpyxl.Workbook): SS7物件新規作成ツール.xlsm
        steelkind (str): 鋼材の種類
        steeltype (str): 鋼材の系列
    """
    tablename: str = "name=円形鋼管"
    record = ss7csv.GetTableData(data, tablename)[0]  # 登録済みの１レコード
    # レコードを削除
    ss7csv.Delete_Record(data, tablename)
    # レコード開始位置
    rowindex: int = ss7csv.GetDataRowIndex(data, tablename)

    # 鋼材リストシート
    sheetBox = wb[steelkind]

    # 鋼材の系列の開始列
    start_col: str = inputreader.get_steel_list_pos_startcol(steelkind, steeltype)
    end_row: int = inputreader.get_steel_list_pos_endrow(steelkind, steeltype)

    index: int = 0
    for row in range(4, end_row):
        record1: List[str] = record.copy()  # ひな形のレコードをもとにコピーを生成
        record1[0] = str(index + 1)
        for i in range(4):
            cellname = get_column_letter(column_index_from_string(start_col) + i)
            cellname += str(row)
            record1[i + 1] = str(sheetBox[cellname].value)
        data.insert(rowindex + index, record1)
        index += 1


def write_steel_list(
    data: List[List[str]],
    wb: openpyxl.Workbook,
    steelkind: str,
    steeltype: str,
) -> None:
    """鋼材リスト

    Args:
        data (List[List[str]]): 入力CSVデータ
        wb (openpyxl.Workbook): SS7物件新規作成ツール.xlsm
        steelkind (str): 鋼材の種類
        steeltype (str): 鋼材の系列
    """
    if "H形鋼１" in steelkind or "H形鋼２" in steelkind:
        write_steel_h(data, wb, steelkind, steeltype)
    elif "角形鋼管" in steelkind:
        write_steel_box(data, wb, steelkind, steeltype)
    elif "円形鋼管" in steelkind:
        write_steel_pipe(data, wb, steelkind, steeltype)
